{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBh => "E h B",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Eh => "E h\N{U+202f}a",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "G y",
    GyM => "G y-MM",
    GyMEd => "G y-MM-dd, E",
    GyMMM => "G y MMM",
    GyMMMEd => "G y MMM d, E",
    GyMMMd => "G y MMM d",
    GyMd => "G y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    Hv => "HH v",
    M => "L",
    MEd => "MM-dd, E",
    MMM => "LLL",
    MMMEd => "MMM d, E",
    "MMMMW-count-one" => "'iveki' W 'ka' MMMM",
    "MMMMW-count-other" => "'iveki' W 'ka' MMMM",
    MMMMd => "MMMM d",
    MMMd => "MMM d",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    hv => "h\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E, M/d/y",
    yMMM => "MMM y",
    yMMMEd => "E, MMM d, y",
    yMMMM => "MMMM y",
    yMMMd => "MMM d, y",
    yMd => "M/d/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'iveki' w 'ka' Y",
    "yw-count-other" => "'iveki' w 'ka' Y",
  },
  code => "xh",
  date_format_full => "EEEE, MMMM d, y",
  date_format_long => "MMMM d, y",
  date_format_medium => "MMM d, y",
  date_format_short => "M/d/yy",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "Mvu",
    "Lwesb",
    "Tha",
    "Sin",
    "Hla",
    "Mgq",
    "Caw",
  ],
  day_format_narrow => [
    "Mv",
    "Sb",
    "Tht",
    "Sin",
    "Hl",
    "Mg",
    "C",
  ],
  day_format_wide => [
    "Mvulo",
    "Lwesibini",
    "Lwesithathu",
    "Lwesine",
    "Lwesihlanu",
    "Mgqibelo",
    "Cawe",
  ],
  day_stand_alone_abbreviated => [
    "Mvu",
    "Bin",
    "Tha",
    "Sin",
    "Hla",
    "Mgq",
    "Caw",
  ],
  day_stand_alone_narrow => [
    "Mv",
    "Sb",
    "St",
    "Sin",
    "Hl",
    "Mg",
    "C",
  ],
  day_stand_alone_wide => [
    "Mvulo",
    "Lwesibini",
    "Lwesithathu",
    "Lwesine",
    "Lwesihlanu",
    "Mgqibelo",
    "Cawe",
  ],
  era_abbreviated => [
    "BC",
    "AD",
  ],
  era_narrow => [
    "BC",
    "AD",
  ],
  era_wide => [
    "Phambi KoKristu",
    "Anno Domino",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %b %e %H:%M:%S %Z %Y",
  glibc_date_format => "%m/%d/%y",
  glibc_datetime_format => "%a %b %e %H:%M:%S %Y",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Xhosa",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mat",
    "Epr",
    "Mey",
    "Jun",
    "Jul",
    "Aga",
    "Sept",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Janyuwari",
    "Februwari",
    "Matshi",
    "Epreli",
    "Meyi",
    "Juni",
    "Julayi",
    "Agasti",
    "Septemba",
    "Okthobha",
    "Novemba",
    "Disemba",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mat",
    "Epr",
    "Mey",
    "Jun",
    "Jul",
    "Aga",
    "Sep",
    "Okt",
    "Nov",
    "Dis",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Janyuwari",
    "Februwari",
    "Matshi",
    "Epreli",
    "Meyi",
    "Juni",
    "Julayi",
    "Agasti",
    "Septemba",
    "Okthoba",
    "Novemba",
    "Disemba",
  ],
  name => "Xhosa",
  native_language => "IsiXhosa",
  native_name => "IsiXhosa",
  native_script => undef,
  native_territory => undef,
  native_variant => undef,
  quarter_format_abbreviated => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "ikota yoku-1",
    "ikota yesi-2",
    "ikota yesi-3",
    "ikota yesi-4",
  ],
  quarter_stand_alone_abbreviated => [
    "Kota 1",
    "Kota 2",
    "Kota 3",
    "Kota 4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "ikota yoku-1",
    "ikota yesi-2",
    "ikota yesi-3",
    "ikota yesi-4",
  ],
  script => undef,
  territory => undef,
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 48,
}
