{
  am_pm_abbreviated => [
    "fm",
    "em",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h.mm B",
    Bhms => "h.mm.ss B",
    E => "ccc",
    EBh => "E h B",
    EBhm => "E h.mm B",
    EBhms => "E h.mm.ss B",
    EHm => "E HH.mm",
    EHms => "E HH.mm.ss",
    Ed => "E d",
    Eh => "E h\N{U+202f}a",
    Ehm => "E h.mm\N{U+202f}a",
    Ehms => "E h.mm.ss\N{U+202f}a",
    Gy => "y G",
    GyM => "M.y G",
    GyMEd => "E d.M.y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d.M.y G",
    H => "H",
    Hm => "HH.mm",
    Hms => "HH.mm.ss",
    Hmsv => "HH.mm.ss v",
    Hmv => "HH.mm v",
    Hv => "HH v",
    M => "L",
    MEd => "E d.M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    MMMMEd => "E d MMMM",
    "MMMMW-count-one" => "'vecka' W 'i' MMMM",
    "MMMMW-count-other" => "'vecka' W 'i' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    MMd => "d.M",
    MMdd => "dd.MM",
    Md => "d.M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h.mm\N{U+202f}a",
    hms => "h.mm.ss\N{U+202f}a",
    hmsv => "h.mm.ss\N{U+202f}a v",
    hmv => "h.mm\N{U+202f}a v",
    hv => "h\N{U+202f}a v",
    ms => "mm.ss",
    y => "y",
    yM => "L.y",
    yMEd => "E d.M.y",
    yMM => "M.y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d.M.y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-one" => "'vecka' w, Y",
    "yw-count-other" => "'vecka' w, Y",
  },
  code => "sv-FI",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d.M.y",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1} {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "m\N{U+00e5}n",
    "tis",
    "ons",
    "tors",
    "fre",
    "l\N{U+00f6}r",
    "s\N{U+00f6}n",
  ],
  day_format_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_format_wide => [
    "m\N{U+00e5}ndag",
    "tisdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f6}rdag",
    "s\N{U+00f6}ndag",
  ],
  day_stand_alone_abbreviated => [
    "m\N{U+00e5}n",
    "tis",
    "ons",
    "tors",
    "fre",
    "l\N{U+00f6}r",
    "s\N{U+00f6}n",
  ],
  day_stand_alone_narrow => [
    "M",
    "T",
    "O",
    "T",
    "F",
    "L",
    "S",
  ],
  day_stand_alone_wide => [
    "m\N{U+00e5}ndag",
    "tisdag",
    "onsdag",
    "torsdag",
    "fredag",
    "l\N{U+00f6}rdag",
    "s\N{U+00f6}ndag",
  ],
  era_abbreviated => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_narrow => [
    "f.Kr.",
    "e.Kr.",
  ],
  era_wide => [
    "f\N{U+00f6}re Kristus",
    "efter Kristus",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %-d.%-m.%Y %H.%M.%S %z",
  glibc_date_format => "%d.%m.%Y",
  glibc_datetime_format => "%a %e. %B %Y %H.%M.%S",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H.%M.%S",
  language => "Swedish",
  month_format_abbreviated => [
    "jan.",
    "feb.",
    "mars",
    "apr.",
    "maj",
    "juni",
    "juli",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "januari",
    "februari",
    "mars",
    "april",
    "maj",
    "juni",
    "juli",
    "augusti",
    "september",
    "oktober",
    "november",
    "december",
  ],
  month_stand_alone_abbreviated => [
    "jan.",
    "feb.",
    "mars",
    "apr.",
    "maj",
    "juni",
    "juli",
    "aug.",
    "sep.",
    "okt.",
    "nov.",
    "dec.",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "januari",
    "februari",
    "mars",
    "april",
    "maj",
    "juni",
    "juli",
    "augusti",
    "september",
    "oktober",
    "november",
    "december",
  ],
  name => "Swedish Finland",
  native_language => "svenska",
  native_name => "svenska Finland",
  native_script => undef,
  native_territory => "Finland",
  native_variant => undef,
  quarter_format_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1:a kvartalet",
    "2:a kvartalet",
    "3:e kvartalet",
    "4:e kvartalet",
  ],
  quarter_stand_alone_abbreviated => [
    "K1",
    "K2",
    "K3",
    "K4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1:a kvartalet",
    "2:a kvartalet",
    "3:e kvartalet",
    "4:e kvartalet",
  ],
  script => undef,
  territory => "Finland",
  time_format_full => "HH.mm.ss zzzz",
  time_format_long => "H.mm.ss z",
  time_format_medium => "H.mm.ss",
  time_format_short => "H.mm",
  variant => undef,
  version => 48,
}
