{
  am_pm_abbreviated => [
    "atm",
    "ptm",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBh => "E h B",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d, E",
    Eh => "E h\N{U+202f}a",
    Ehm => "E h:mm\N{U+202f}a",
    Ehms => "E h:mm:ss\N{U+202f}a",
    Gy => "y G",
    GyM => "G y-MM",
    GyMEd => "E, d MMM y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E, d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "d MMM y G",
    H => "HH'H'",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    Hv => "HH'H' v",
    M => "L",
    MEd => "E, MM-dd",
    MMM => "MMM",
    MMMEd => "E, d MMM",
    "MMMMW-count-one" => "W-'a' 'semajno' 'de' MMMM",
    "MMMMW-count-other" => "W-'a' 'semajno' 'de' MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "MM-dd",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm\N{U+202f}a",
    hms => "h:mm:ss\N{U+202f}a",
    hmsv => "h:mm:ss\N{U+202f}a v",
    hmv => "h:mm\N{U+202f}a v",
    hv => "h\N{U+202f}a v",
    ms => "mm:ss",
    y => "y",
    yM => "y-MM",
    yMEd => "E, y-MM-dd",
    yMMM => "MMM y",
    yMMMEd => "E, d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "y-MM-dd",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ 'de' y",
    "yw-count-one" => "w-'a' 'semajno' 'de' Y",
    "yw-count-other" => "w-'a' 'semajno' 'de' Y",
  },
  code => "eo-001",
  date_format_full => "EEEE, 'la' d-'a' 'de' MMMM y",
  date_format_long => "y-MMMM-dd",
  date_format_medium => "y-MMM-dd",
  date_format_short => "yy-MM-dd",
  datetime_format_full => "{1} {0}",
  datetime_format_long => "{1} {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1} {0}",
  day_format_abbreviated => [
    "lu",
    "ma",
    "me",
    "\N{U+0135}a",
    "ve",
    "sa",
    "di",
  ],
  day_format_narrow => [
    "l",
    "m",
    "m",
    "\N{U+0135}",
    "v",
    "s",
    "d",
  ],
  day_format_wide => [
    "lundo",
    "mardo",
    "merkredo",
    "\N{U+0135}a\N{U+016d}do",
    "vendredo",
    "sabato",
    "diman\N{U+0109}o",
  ],
  day_stand_alone_abbreviated => [
    "lu",
    "ma",
    "me",
    "\N{U+0135}a",
    "ve",
    "sa",
    "di",
  ],
  day_stand_alone_narrow => [
    "l",
    "m",
    "m",
    "\N{U+0135}",
    "v",
    "s",
    "d",
  ],
  day_stand_alone_wide => [
    "lundo",
    "mardo",
    "merkredo",
    "\N{U+0135}a\N{U+016d}do",
    "vendredo",
    "sabato",
    "diman\N{U+0109}o",
  ],
  era_abbreviated => [
    "a.n.e.",
    "n.e.",
  ],
  era_narrow => [
    "a.n.e.",
    "n.e.",
  ],
  era_wide => [
    "anta\N{U+016d} nia erao",
    "de nia erao",
  ],
  first_day_of_week => 1,
  glibc_date_1_format => "%a %d %b %Y %T %z",
  glibc_date_format => "%Y-%m-%d",
  glibc_datetime_format => "%a %d %b %Y %T",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%T",
  language => "Esperanto",
  month_format_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Maj",
    "Jun",
    "Jul",
    "A\N{U+016d}g",
    "Sep",
    "Okt",
    "Nov",
    "Dec",
  ],
  month_format_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_format_wide => [
    "Januaro",
    "Februaro",
    "Marto",
    "Aprilo",
    "Majo",
    "Junio",
    "Julio",
    "A\N{U+016d}gusto",
    "Septembro",
    "Oktobro",
    "Novembro",
    "Decembro",
  ],
  month_stand_alone_abbreviated => [
    "Jan",
    "Feb",
    "Mar",
    "Apr",
    "Maj",
    "Jun",
    "Jul",
    "A\N{U+016d}g",
    "Sep",
    "Okt",
    "Nov",
    "Dec",
  ],
  month_stand_alone_narrow => [
    "J",
    "F",
    "M",
    "A",
    "M",
    "J",
    "J",
    "A",
    "S",
    "O",
    "N",
    "D",
  ],
  month_stand_alone_wide => [
    "Januaro",
    "Februaro",
    "Marto",
    "Aprilo",
    "Majo",
    "Junio",
    "Julio",
    "A\N{U+016d}gusto",
    "Septembro",
    "Oktobro",
    "Novembro",
    "Decembro",
  ],
  name => "Esperanto world",
  native_language => "Esperanto",
  native_name => "Esperanto mondo",
  native_script => undef,
  native_territory => "mondo",
  native_variant => undef,
  quarter_format_abbreviated => [
    "1. jk.",
    "2. jk.",
    "3. jk.",
    "4. jk.",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "1-a jarkvarono",
    "2-a jarkvarono",
    "3-a jarkvarono",
    "4-a jarkvarono",
  ],
  quarter_stand_alone_abbreviated => [
    "1. jk.",
    "2. jk.",
    "3. jk.",
    "4. jk.",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "1-a jarkvarono",
    "2-a jarkvarono",
    "3-a jarkvarono",
    "4-a jarkvarono",
  ],
  script => undef,
  territory => "world",
  time_format_full => "HH:mm:ss zzzz",
  time_format_long => "HH:mm:ss z",
  time_format_medium => "HH:mm:ss",
  time_format_short => "HH:mm",
  variant => undef,
  version => 48,
}
